#line 1 "kate_lexer.c"

#line 3 "kate_lexer.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define yy_create_buffer katedesc__create_buffer
#define yy_delete_buffer katedesc__delete_buffer
#define yy_scan_buffer katedesc__scan_buffer
#define yy_scan_string katedesc__scan_string
#define yy_scan_bytes katedesc__scan_bytes
#define yy_init_buffer katedesc__init_buffer
#define yy_flush_buffer katedesc__flush_buffer
#define yy_load_buffer_state katedesc__load_buffer_state
#define yy_switch_to_buffer katedesc__switch_to_buffer
#define yypush_buffer_state katedesc_push_buffer_state
#define yypop_buffer_state katedesc_pop_buffer_state
#define yyensure_buffer_stack katedesc_ensure_buffer_stack
#define yy_flex_debug katedesc__flex_debug
#define yyin katedesc_in
#define yyleng katedesc_leng
#define yylex katedesc_lex
#define yylineno katedesc_lineno
#define yyout katedesc_out
#define yyrestart katedesc_restart
#define yytext katedesc_text
#define yywrap katedesc_wrap
#define yyalloc katedesc_alloc
#define yyrealloc katedesc_realloc
#define yyfree katedesc_free

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 6
#define YY_FLEX_SUBMINOR_VERSION 4
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

#ifdef yy_create_buffer
#define katedesc__create_buffer_ALREADY_DEFINED
#else
#define yy_create_buffer katedesc__create_buffer
#endif

#ifdef yy_delete_buffer
#define katedesc__delete_buffer_ALREADY_DEFINED
#else
#define yy_delete_buffer katedesc__delete_buffer
#endif

#ifdef yy_scan_buffer
#define katedesc__scan_buffer_ALREADY_DEFINED
#else
#define yy_scan_buffer katedesc__scan_buffer
#endif

#ifdef yy_scan_string
#define katedesc__scan_string_ALREADY_DEFINED
#else
#define yy_scan_string katedesc__scan_string
#endif

#ifdef yy_scan_bytes
#define katedesc__scan_bytes_ALREADY_DEFINED
#else
#define yy_scan_bytes katedesc__scan_bytes
#endif

#ifdef yy_init_buffer
#define katedesc__init_buffer_ALREADY_DEFINED
#else
#define yy_init_buffer katedesc__init_buffer
#endif

#ifdef yy_flush_buffer
#define katedesc__flush_buffer_ALREADY_DEFINED
#else
#define yy_flush_buffer katedesc__flush_buffer
#endif

#ifdef yy_load_buffer_state
#define katedesc__load_buffer_state_ALREADY_DEFINED
#else
#define yy_load_buffer_state katedesc__load_buffer_state
#endif

#ifdef yy_switch_to_buffer
#define katedesc__switch_to_buffer_ALREADY_DEFINED
#else
#define yy_switch_to_buffer katedesc__switch_to_buffer
#endif

#ifdef yypush_buffer_state
#define katedesc_push_buffer_state_ALREADY_DEFINED
#else
#define yypush_buffer_state katedesc_push_buffer_state
#endif

#ifdef yypop_buffer_state
#define katedesc_pop_buffer_state_ALREADY_DEFINED
#else
#define yypop_buffer_state katedesc_pop_buffer_state
#endif

#ifdef yyensure_buffer_stack
#define katedesc_ensure_buffer_stack_ALREADY_DEFINED
#else
#define yyensure_buffer_stack katedesc_ensure_buffer_stack
#endif

#ifdef yylex
#define katedesc_lex_ALREADY_DEFINED
#else
#define yylex katedesc_lex
#endif

#ifdef yyrestart
#define katedesc_restart_ALREADY_DEFINED
#else
#define yyrestart katedesc_restart
#endif

#ifdef yylex_init
#define katedesc_lex_init_ALREADY_DEFINED
#else
#define yylex_init katedesc_lex_init
#endif

#ifdef yylex_init_extra
#define katedesc_lex_init_extra_ALREADY_DEFINED
#else
#define yylex_init_extra katedesc_lex_init_extra
#endif

#ifdef yylex_destroy
#define katedesc_lex_destroy_ALREADY_DEFINED
#else
#define yylex_destroy katedesc_lex_destroy
#endif

#ifdef yyget_debug
#define katedesc_get_debug_ALREADY_DEFINED
#else
#define yyget_debug katedesc_get_debug
#endif

#ifdef yyset_debug
#define katedesc_set_debug_ALREADY_DEFINED
#else
#define yyset_debug katedesc_set_debug
#endif

#ifdef yyget_extra
#define katedesc_get_extra_ALREADY_DEFINED
#else
#define yyget_extra katedesc_get_extra
#endif

#ifdef yyset_extra
#define katedesc_set_extra_ALREADY_DEFINED
#else
#define yyset_extra katedesc_set_extra
#endif

#ifdef yyget_in
#define katedesc_get_in_ALREADY_DEFINED
#else
#define yyget_in katedesc_get_in
#endif

#ifdef yyset_in
#define katedesc_set_in_ALREADY_DEFINED
#else
#define yyset_in katedesc_set_in
#endif

#ifdef yyget_out
#define katedesc_get_out_ALREADY_DEFINED
#else
#define yyget_out katedesc_get_out
#endif

#ifdef yyset_out
#define katedesc_set_out_ALREADY_DEFINED
#else
#define yyset_out katedesc_set_out
#endif

#ifdef yyget_leng
#define katedesc_get_leng_ALREADY_DEFINED
#else
#define yyget_leng katedesc_get_leng
#endif

#ifdef yyget_text
#define katedesc_get_text_ALREADY_DEFINED
#else
#define yyget_text katedesc_get_text
#endif

#ifdef yyget_lineno
#define katedesc_get_lineno_ALREADY_DEFINED
#else
#define yyget_lineno katedesc_get_lineno
#endif

#ifdef yyset_lineno
#define katedesc_set_lineno_ALREADY_DEFINED
#else
#define yyset_lineno katedesc_set_lineno
#endif

#ifdef yywrap
#define katedesc_wrap_ALREADY_DEFINED
#else
#define yywrap katedesc_wrap
#endif

#ifdef yyalloc
#define katedesc_alloc_ALREADY_DEFINED
#else
#define yyalloc katedesc_alloc
#endif

#ifdef yyrealloc
#define katedesc_realloc_ALREADY_DEFINED
#else
#define yyrealloc katedesc_realloc
#endif

#ifdef yyfree
#define katedesc_free_ALREADY_DEFINED
#else
#define yyfree katedesc_free
#endif

#ifdef yytext
#define katedesc_text_ALREADY_DEFINED
#else
#define yytext katedesc_text
#endif

#ifdef yyleng
#define katedesc_leng_ALREADY_DEFINED
#else
#define yyleng katedesc_leng
#endif

#ifdef yyin
#define katedesc_in_ALREADY_DEFINED
#else
#define yyin katedesc_in
#endif

#ifdef yyout
#define katedesc_out_ALREADY_DEFINED
#else
#define yyout katedesc_out
#endif

#ifdef yy_flex_debug
#define katedesc__flex_debug_ALREADY_DEFINED
#else
#define yy_flex_debug katedesc__flex_debug
#endif

#ifdef yylineno
#define katedesc_lineno_ALREADY_DEFINED
#else
#define yylineno katedesc_lineno
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#ifndef SIZE_MAX
#define SIZE_MAX               (~(size_t)0)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

/* begin standard C++ headers. */

/* TODO: this is always defined, so inline it */
#define yyconst const

#if defined(__GNUC__) && __GNUC__ >= 3
#define yynoreturn __attribute__((__noreturn__))
#else
#define yynoreturn
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an
 *   integer in range [0..255] for use as an array index.
 */
#define YY_SC_TO_UI(c) ((YY_CHAR) (c))

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *
/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START
/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)
/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart( yyin  )
#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

extern int yyleng;

extern FILE *yyin, *yyout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2
    
    #define YY_LESS_LINENO(n)
    #define YY_LINENO_REWIND_TO(ptr)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )
#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	int yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */

	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = NULL; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)
/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when yytext is formed. */
static char yy_hold_char;
static int yy_n_chars;		/* number of characters read into yy_ch_buf */
int yyleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = NULL;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow yywrap()'s to do buffer switches
 * instead of setting up a fresh yyin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void yyrestart ( FILE *input_file  );
void yy_switch_to_buffer ( YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE yy_create_buffer ( FILE *file, int size  );
void yy_delete_buffer ( YY_BUFFER_STATE b  );
void yy_flush_buffer ( YY_BUFFER_STATE b  );
void yypush_buffer_state ( YY_BUFFER_STATE new_buffer  );
void yypop_buffer_state ( void );

static void yyensure_buffer_stack ( void );
static void yy_load_buffer_state ( void );
static void yy_init_buffer ( YY_BUFFER_STATE b, FILE *file  );
#define YY_FLUSH_BUFFER yy_flush_buffer( YY_CURRENT_BUFFER )

YY_BUFFER_STATE yy_scan_buffer ( char *base, yy_size_t size  );
YY_BUFFER_STATE yy_scan_string ( const char *yy_str  );
YY_BUFFER_STATE yy_scan_bytes ( const char *bytes, int len  );

void *yyalloc ( yy_size_t  );
void *yyrealloc ( void *, yy_size_t  );
void yyfree ( void *  );

#define yy_new_buffer yy_create_buffer
#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}
#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}
#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */
typedef flex_uint8_t YY_CHAR;

FILE *yyin = NULL, *yyout = NULL;

typedef int yy_state_type;

extern int yylineno;
int yylineno = 1;

extern char *yytext;
#ifdef yytext_ptr
#undef yytext_ptr
#endif
#define yytext_ptr yytext

static yy_state_type yy_get_previous_state ( void );
static yy_state_type yy_try_NUL_trans ( yy_state_type current_state  );
static int yy_get_next_buffer ( void );
static void yynoreturn yy_fatal_error ( const char* msg  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	(yytext_ptr) -= (yy_more_len); \
	yyleng = (int) (yy_cp - (yytext_ptr)); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;
#define YY_NUM_RULES 145
#define YY_END_OF_BUFFER 146
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static const flex_int16_t yy_accept[693] =
    {   0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
      146,    3,    3,   16,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,  144,
       15,   16,  144,  144,  144,  144,  144,  144,  144,  137,
      137,  144,  144,  144,  144,  144,  144,  144,  144,  144,
      144,  144,  144,  144,  144,  144,  144,  144,  144,  144,
      144,  144,  144,    5,    7,    5,  145,  145,    9,   10,
       12,   13,  145,   15,    0,  136,    0,   14,    0,   18,

        0,  137,  137,    0,  139,  139,  141,    0,  141,    0,
        0,    0,   46,   61,    0,   29,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,   86,  134,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,   60,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,   64,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    1,    4,    5,    6,    0,    8,    9,   10,

       12,   11,    0,   18,   51,    0,    0,    0,    0,  141,
      138,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,   48,
        0,    0,    0,    0,   62,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,  116,
        0,    0,    0,    0,    0,  116,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
      105,    0,    0,  108,  117,    0,    0,    0,    0,  117,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,   98,    0,    0,    0,    0,    0,    0,    0,

        0,    0,    0,    0,    0,    2,    0,  140,    0,  141,
        0,    0,    0,    0,   87,    0,    0,    0,    0,    0,
      107,   79,    0,    0,    0,    0,    0,   19,    0,   83,
        0,   45,    0,    0,    0,   75,    0,   63,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,   17,
        0,    0,   78,   97,    0,    0,    0,    0,    0,    0,
        0,  115,    0,    0,    0,   55,    0,    0,   69,    0,
        0,    0,    0,    0,    0,    0,    0,   93,    0,    0,
        0,    0,    0,    0,    0,    0,   33,    0,    0,    0,
        0,    0,    0,   27,   49,    0,    0,   81,    0,    0,

        0,    0,    0,   41,    0,  114,  113,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,   30,    0,   26,
        0,    0,    0,    0,   20,    0,   77,   54,  132,    0,
        0,    0,    0,   38,    0,    0,    0,    0,    0,    0,
        0,    0,    0,  111,    0,   65,    0,    0,    0,    0,
        0,   67,    0,    0,    0,  135,    0,    0,  121,   80,
        0,    0,   76,    0,   99,    0,    0,    0,    0,   94,
        0,    0,   47,    0,    0,   24,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,   95,    0,    0,
        0,    0,   73,  100,    0,  110,    0,    0,   74,    0,

        0,   23,    0,    0,    0,    0,   34,    0,   96,    0,
       40,    0,    0,    0,    0,    0,    0,  126,    0,    0,
      101,   31,  109,    0,   52,  112,    0,    0,    0,  120,
        0,   37,    0,    0,   25,    0,    0,    0,    0,    0,
        0,   82,   44,  125,   90,    0,    0,    0,    0,    0,
        0,   35,    0,    0,    0,    0,  142,    0,    0,    0,
      129,    0,    0,   22,   36,    0,    0,    0,   92,   39,
        0,    0,   88,  106,  116,    0,    0,  116,   53,  102,
        0,   72,  123,    0,  133,    0,  117,    0,  117,    0,
       70,    0,    0,  119,  118,    0,  119,  118,    0,   43,

       42,    0,   84,    0,    0,    0,    0,   85,    0,    0,
       50,   57,    0,   58,   21,    0,    0,    0,   91,   32,
        0,    0,    0,    0,   66,    0,  104,  143,   59,    0,
        0,    0,    0,    0,    0,    0,    0,    0,   68,   56,
        0,   89,   28,    0,    0,    0,  103,    0,  124,  122,
        0,    0,    0,  127,    0,    0,    0,    0,  128,    0,
        0,    0,    0,    0,  116,  117,    0,   71,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,  130,    0,    0,    0,    0,    0,
      131,    0

    } ;

static const YY_CHAR yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    4,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    1,    5,    6,    7,    1,    1,    1,    1,
        1,    8,    9,    1,   10,   11,   12,   13,   14,   15,
       14,   14,   14,   14,   14,   14,   14,    1,    1,    1,
        1,   16,    1,    1,   17,   18,   19,   20,   21,   22,
       23,   24,   25,   26,   27,   28,   29,   30,   31,   32,
       33,   34,   35,   36,   37,   38,   39,   40,   41,   42,
        1,   43,    1,    1,   44,    1,   45,   46,   47,   48,

       49,   50,   51,   52,   53,   54,   55,   56,   57,   58,
       59,   60,   33,   61,   62,   63,   64,   65,   66,   67,
       68,   69,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,   70,    1,    1,    1,
       71,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,   72,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,   73,   74
    } ;

static const YY_CHAR yy_meta[75] =
    {   0,
        1,    1,    2,    1,    1,    1,    1,    3,    1,    1,
        1,    1,    4,    4,    4,    1,    5,    5,    5,    5,
        5,    5,    6,    6,    6,    6,    6,    6,    6,    6,
        6,    6,    6,    6,    6,    6,    6,    6,    6,    6,
        6,    6,    7,    6,    5,    5,    5,    5,    5,    5,
        6,    6,    6,    6,    6,    6,    6,    6,    6,    6,
        6,    6,    6,    6,    6,    6,    6,    6,    6,    1,
        1,    1,    1,    1
    } ;

static const flex_int16_t yy_base[707] =
    {   0,
        0,    0,   74,    0,  146,  148,  156,  230,  150,  152,
      668, 1807,  665, 1807, 1807,  632,  302,    0,  162,  168,
      171,  620,  239,  176,  152,  336,  230,  234,  226,  301,
      229,  382,  307,  137,  175,  369,  409,  163,  174,  452,
      400,  435,  343,  278,  497,  447,  529,  514,  479, 1807,
      545, 1807,  529,  558,    0,  189,  196,  199,  209,  514,
      362,  282,    0,  448,  549,  500,  492,  363,    0,  501,
      212,  206,  594,  595,  238,  259,    0,  635,  610,  602,
      377,    0,  611,    0, 1807,    0,  262, 1807,  530,    0,
        0, 1807,  500,  497,  485, 1807,  486, 1807,  686,    0,

      315,  676,  579,  441,  681,  664,  696,  452,  705,  714,
        0,  286, 1807,  295,  223, 1807,  236,  439,  309,  526,
      319,  718,  246,  358,  332,  392,  386,  413,  421,  428,
      458,  707,  722,  468,  429,  424,  475,  495,  520,  505,
      532, 1807,  519,  551,  552,  555,  561,  714,  579,  591,
      693,  563,  723,  630,  694,  724,  721,  730,  741,  725,
      721,  739,  738,  743,  743,  759,  759, 1807,  770,  768,
      779,  776,  773,  769,  786,  789,  771,  780,  780,  795,
      796,  797,  795,  794,  807,  798,  799,  808,  823,  811,
      831,  379, 1807, 1807,    0, 1807,  270, 1807,  446,    0,

        0, 1807,  864,    0, 1807,    0,  855,  441,  668,  860,
        0,  829,  833,  837,  834,  846,  853,  859,  854,  872,
      863,  875,  866,  869,  862,  903,  881,  865,  888,  872,
      878,  896,  887,  896, 1807,  889,  906,  907,  910,  916,
      912,  920,  922,  922,  927,  930,  924,  901,  932,  360,
      931,  921,  922,  934,  943,  344,  928,  934,  950,  957,
      948,  954,  962,  969,  957,  972,  971,  962,  981,  977,
     1807,  969,  978, 1807,  338,  984,  987,  984,  986,  334,
      980,  995,  991,  985,  999,  988,  996, 1000, 1005,  319,
      993, 1021, 1807,  312, 1023, 1012, 1022, 1014, 1021, 1018,

     1027, 1023, 1022, 1040, 1030, 1807, 1078,    0, 1050, 1053,
     1044, 1053, 1057, 1065, 1807, 1053, 1061, 1070, 1066, 1057,
     1807, 1807, 1069, 1080, 1084, 1070, 1078, 1807, 1090, 1807,
     1075, 1807, 1077, 1082, 1082, 1807, 1098, 1807, 1096, 1085,
     1108, 1099, 1108, 1103, 1099, 1118, 1110, 1121, 1125, 1807,
     1116, 1116, 1807,  302, 1137, 1127, 1121, 1127, 1136, 1138,
     1144, 1807, 1139, 1143, 1138, 1807, 1151, 1139, 1807, 1152,
     1155, 1146, 1157, 1151, 1152, 1154, 1173, 1807, 1165, 1162,
     1163, 1173, 1181, 1177, 1173, 1182, 1807, 1192, 1180, 1187,
     1191, 1198, 1193, 1807, 1202, 1195, 1194, 1807, 1207, 1196,

     1197, 1212, 1223, 1807, 1218, 1807, 1807, 1258, 1224, 1223,
     1227, 1230, 1234, 1234, 1231, 1236, 1240, 1239, 1252, 1807,
     1255, 1264, 1251, 1264, 1807, 1264, 1807, 1807, 1807, 1269,
     1268, 1278, 1266, 1807, 1269, 1273, 1282, 1296, 1294,  319,
     1301, 1284, 1287, 1807, 1287, 1807, 1294, 1300, 1298, 1301,
     1303, 1807, 1305, 1301, 1302, 1807, 1309, 1321, 1310, 1321,
     1324,  318, 1807, 1321,  287, 1317, 1334, 1326, 1324, 1807,
     1345, 1347, 1336, 1354, 1353, 1807,  310,  297, 1358, 1342,
     1345, 1348, 1354, 1355, 1367, 1370, 1362, 1807, 1406, 1385,
     1376,  252, 1807, 1807, 1388, 1807, 1361, 1382, 1807, 1377,

     1379, 1807, 1386, 1398, 1413, 1410, 1807, 1399, 1807, 1406,
     1807, 1424, 1408, 1403, 1427, 1423, 1416, 1807, 1430, 1426,
     1426, 1807, 1807, 1420, 1807, 1807, 1441, 1429, 1438, 1807,
     1432, 1807, 1436, 1450, 1807, 1436, 1461, 1463, 1451, 1457,
      233, 1807, 1807, 1807, 1807, 1450, 1457, 1452, 1455, 1466,
     1472, 1807, 1469, 1466, 1484, 1481, 1518, 1476, 1478, 1498,
     1807, 1478,  218, 1807, 1807, 1489, 1491, 1495, 1807, 1807,
     1492, 1496, 1807, 1807, 1807, 1520,  204, 1807, 1807, 1807,
     1507, 1807, 1527, 1528, 1807, 1520, 1807, 1522, 1807, 1522,
     1807, 1535, 1521, 1807, 1807, 1537, 1807, 1807, 1529, 1807,

     1807, 1532, 1807, 1576, 1537, 1541, 1537, 1807, 1542, 1547,
     1807, 1807, 1562, 1807, 1807, 1551, 1556, 1569, 1807, 1807,
      175, 1561, 1569, 1581, 1807, 1588, 1807,  215, 1807, 1590,
     1593, 1582, 1597, 1587, 1591, 1583, 1598, 1599, 1807, 1807,
     1599, 1807, 1807, 1605, 1603, 1605, 1807, 1612, 1807, 1807,
     1615, 1619, 1627, 1807, 1623, 1625, 1628, 1631, 1807, 1617,
     1618, 1621,  172, 1618, 1807, 1807, 1639, 1807, 1637, 1626,
     1637, 1646,  161, 1653, 1654, 1637, 1641, 1644, 1656, 1661,
     1670, 1671, 1653,  154, 1807, 1666, 1665, 1667, 1671, 1680,
     1807, 1807, 1732, 1739, 1746, 1753, 1760, 1763, 1769, 1776,

     1780, 1786, 1789, 1795, 1799, 1801
    } ;

static const flex_int16_t yy_def[707] =
    {   0,
      692,    1,  692,    3,  693,  693,  694,  694,  695,  695,
      692,  692,  692,  692,  692,  696,  697,  698,  692,  692,
      692,  692,  692,  692,  692,  692,  692,  692,  692,  692,
      692,  692,  692,  692,  692,  692,  692,  692,  692,  692,
      692,  692,  692,  692,  692,  692,  692,  692,  692,  692,
      692,  692,  696,  697,  698,  692,  692,  692,  692,  692,
      692,  692,   26,  692,  692,  692,  692,  692,   32,  692,
      692,  692,  692,  692,  692,  692,   40,  692,  692,  692,
      692,   45,  692,  699,  692,  699,  700,  692,  692,  701,
      702,  692,  692,  692,  696,  692,  697,  692,   54,  703,

      692,  692,  692,  692,  692,  692,  692,  704,  692,  692,
      705,  692,  692,  692,  692,  692,  692,  692,  692,  692,
      692,  692,  692,  692,  692,  692,  692,  692,  692,  692,
      692,  692,  692,  692,  692,  692,  692,  692,  692,  692,
      692,  692,  692,  692,  692,  692,  692,  692,  692,  692,
      692,  692,  692,  692,  692,  692,  692,  692,  692,  692,
      692,  692,  692,  692,  692,  692,  692,  692,  692,  692,
      692,  692,  692,  692,  692,  692,  692,  692,  692,  692,
      692,  692,  692,  692,  692,  692,  692,  692,  692,  692,
      692,  692,  692,  692,  699,  692,  700,  692,  692,  701,

      702,  692,   54,  703,  692,  706,  692,  704,  692,  692,
      705,  692,  692,  692,  692,  692,  692,  692,  692,  692,
      692,  692,  692,  692,  692,  692,  692,  692,  692,  692,
      692,  692,  692,  692,  692,  692,  692,  692,  692,  692,
      692,  692,  692,  692,  692,  692,  692,  692,  692,  692,
      692,  692,  692,  692,  692,  692,  692,  692,  692,  692,
      692,  692,  692,  692,  692,  692,  692,  692,  692,  692,
      692,  692,  692,  692,  692,  692,  692,  692,  692,  692,
      692,  692,  692,  692,  692,  692,  692,  692,  692,  692,
      692,  692,  692,  692,  692,  692,  692,  692,  692,  692,

      692,  692,  692,  692,  692,  692,   54,  706,  692,  692,
      692,  692,  692,  692,  692,  692,  692,  692,  692,  692,
      692,  692,  692,  692,  692,  692,  692,  692,  692,  692,
      692,  692,  692,  692,  692,  692,  692,  692,  692,  692,
      692,  692,  692,  692,  692,  692,  692,  692,  692,  692,
      692,  692,  692,  692,  692,  692,  692,  692,  692,  692,
      692,  692,  692,  692,  692,  692,  692,  692,  692,  692,
      692,  692,  692,  692,  692,  692,  692,  692,  692,  692,
      692,  692,  692,  692,  692,  692,  692,  692,  692,  692,
      692,  692,  692,  692,  692,  692,  692,  692,  692,  692,

      692,  692,  692,  692,  692,  692,  692,   54,  692,  692,
      692,  692,  692,  692,  692,  692,  692,  692,  692,  692,
      692,  692,  692,  692,  692,  692,  692,  692,  692,  692,
      692,  692,  692,  692,  692,  692,  692,  692,  692,  692,
      692,  692,  692,  692,  692,  692,  692,  692,  692,  692,
      692,  692,  692,  692,  692,  692,  692,  692,  692,  692,
      692,  692,  692,  692,  692,  692,  692,  692,  692,  692,
      692,  692,  692,  692,  692,  692,  692,  692,  692,  692,
      692,  692,  692,  692,  692,  692,  692,  692,   54,  692,
      692,  692,  692,  692,  692,  692,  692,  692,  692,  692,

      692,  692,  692,  692,  692,  692,  692,  692,  692,  692,
      692,  692,  692,  692,  692,  692,  692,  692,  692,  692,
      692,  692,  692,  692,  692,  692,  692,  692,  692,  692,
      692,  692,  692,  692,  692,  692,  692,  692,  692,  692,
      692,  692,  692,  692,  692,  692,  692,  692,  692,  692,
      692,  692,  692,  692,  692,  692,   54,  692,  692,  692,
      692,  692,  692,  692,  692,  692,  692,  692,  692,  692,
      692,  692,  692,  692,  692,  692,  692,  692,  692,  692,
      692,  692,  692,  692,  692,  692,  692,  692,  692,  692,
      692,  692,  692,  692,  692,  692,  692,  692,  692,  692,

      692,  692,  692,   54,  692,  692,  692,  692,  692,  692,
      692,  692,  692,  692,  692,  692,  692,  692,  692,  692,
      692,  692,  692,  692,  692,  692,  692,  697,  692,  692,
      692,  692,  692,  692,  692,  692,  692,  692,  692,  692,
      692,  692,  692,  692,  692,  692,  692,  692,  692,  692,
      692,  692,  692,  692,  692,  692,  692,  692,  692,  692,
      692,  692,  692,  692,  692,  692,  692,  692,  692,  692,
      692,  692,  692,  692,  692,  692,  692,  692,  692,  692,
      692,  692,  692,  692,  692,  692,  692,  692,  692,  692,
      692,    0,  692,  692,  692,  692,  692,  692,  692,  692,

      692,  692,  692,  692,  692,  692
    } ;

static const flex_int16_t yy_nxt[1882] =
    {   0,
       12,   13,   14,   15,   16,   17,   18,   12,   19,   20,
       21,   22,   23,   24,   24,   12,   25,   26,   27,   28,
       29,   30,   31,   32,   33,   34,   35,   36,   37,   38,
       39,   40,   12,   41,   42,   43,   44,   45,   46,   12,
       12,   12,   12,   12,   25,   26,   27,   28,   29,   30,
       31,   32,   33,   34,   35,   36,   37,   38,   39,   40,
       41,   42,   43,   44,   45,   46,   12,   12,   12,   12,
       12,   47,   48,   49,   50,   51,   14,   52,   53,   54,
       55,   50,   56,   57,   58,   59,   60,   61,   61,   50,
       62,   63,   64,   65,   66,   67,   68,   69,   70,   71,

       72,   73,   74,   75,   76,   77,   50,   78,   79,   80,
       81,   82,   83,   50,   50,   50,   50,   50,   62,   63,
       64,   65,   66,   67,   68,   69,   70,   71,   72,   73,
       74,   75,   76,   77,   78,   79,   80,   81,   82,   83,
       50,   50,   50,   50,   50,   50,   50,   50,   85,   86,
       85,   86,   92,   87,   92,   87,   88,   89,   88,   88,
       88,   88,   88,   88,   88,   88,   88,   88,   88,   88,
       88,   88,  101,  145,  102,  103,  103,  104,  101,  112,
      105,  106,  106,  107,  107,  107,  109,  113,  103,  103,
      103,  146,   93,  157,   93,  158,  110,  686,   88,  101,

      145,  102,  103,  103,  674,  104,  101,  112,  105,  106,
      106,  107,  107,  107,  113,  667,  194,   98,  638,  146,
      108,  157,  146,  158,  110,   88,   88,   88,   88,   88,
       88,   89,   88,   88,   88,   88,   88,   88,   88,   88,
       88,   88,   88,   88,   88,   88,  120,  616,  145,  109,
      146,  103,  103,  103,  124,  128,  134,  121,  125,  110,
      122,  609,  135,  129,  214,  130,  123,  126,  157,  197,
      127,  215,   88,  198,  120,  145,  593,  197,  111,  225,
      158,  198,  124,  128,  134,  121,  125,  110,  122,  135,
      129,  214,  130,  123,  126,  560,  157,  127,  215,   88,

       88,   88,   88,   88,   98,  111,  225,  181,  158,  112,
      212,  547,  182,  213,   99,   99,   99,  113,   99,   99,
       99,   99,   99,   99,  546,  131,  142,  107,  107,  107,
      536,  132,  534,  515,  133,  181,  143,  112,  212,  182,
      218,  213,  144,  221,  113,  442,   99,   99,   99,   99,
       99,   99,  114,  131,  142,  396,  115,  176,  116,  132,
      117,  133,  393,  177,  143,  227,  118,  178,  218,  144,
      119,  221,  109,  179,  103,  103,  103,  381,  180,  226,
      114,  376,  110,  147,  115,  148,  116,  357,  117,  149,
      134,  177,  227,  150,  118,  178,  135,  119,  136,  151,

      137,  179,  138,  351,  152,  180,  181,  226,  228,  139,
      110,  182,  140,  148,  165,  141,  166,  149,  134,  229,
      167,  150,  168,  135,  169,  153,  136,  151,  137,  154,
      138,  152,  230,  155,  181,  170,  228,  139,  182,  156,
      140,  231,  141,   98,  166,  239,  229,  199,  167,  306,
      168,  240,  169,  153,   98,  171,  205,  154,  172,  173,
      230,  155,  170,  232,  120,  174,  216,  156,  159,  231,
      175,  189,  160,  239,  217,  121,  161,  190,  122,  240,
      191,  162,  163,  171,  123,  164,  172,  173,   98,   96,
      232,  233,  120,  174,  216,  241,  159,  175,   94,  189,

      160,  217,  202,  121,  161,  190,  122,  191,  238,  162,
      163,  123,  164,  183,  184,  185,  131,  186,  233,  242,
      142,  187,  132,  241,  109,  133,  103,  103,  103,  128,
      143,  199,  188,   96,  110,  238,  144,  129,  244,  130,
      243,  183,  184,  185,  131,  186,   94,  242,  142,  187,
      132,  193,  133,  111,  246,  219,  245,  128,  143,  188,
       98,  220,  110,  144,  129,  244,  130,  247,  243,  124,
       99,   99,   99,  125,   99,   99,   99,   99,   99,   99,
      111,  246,  126,  219,  245,  127,  248,  193,  220,  109,
      249,  103,  103,  103,  250,  247,  256,  124,  192,  110,

      253,  125,   99,   99,   99,   99,   99,   99,  147,  126,
      148,  153,  127,  248,  149,  154,  176,  249,  150,  155,
      254,  250,  177,  256,  151,  156,  178,  110,  253,  152,
      171,  108,  179,  172,  173,  189,   96,  180,  148,  153,
      174,  190,  149,  154,  191,  175,  150,  155,  254,  165,
      177,  166,  151,  156,  178,  167,  152,  168,  171,  169,
      179,  172,  173,  189,  180,  260,   94,  692,  174,  190,
      170,  191,  175,  692,  109,  692,  106,  106,  106,  166,
      210,  210,  210,  167,  110,  168,  109,  169,  103,  103,
      103,  109,  260,  106,  106,  106,  110,  170,  203,  203,

      203,  110,  203,  203,  203,  203,  203,  203,  107,  107,
      107,  255,  110,  692,  692,  111,  207,  107,  107,  107,
      206,  261,  209,  209,  110,  110,  210,  210,  210,  110,
      203,  203,  203,  203,  203,  203,  234,  222,  236,  255,
      235,  257,  111,  251,  207,  223,  224,  206,  252,  261,
      264,  265,  237,  110,  258,  692,  259,  262,  269,  263,
      270,  271,  272,  274,  234,  222,  236,  235,  266,  257,
      275,  251,  273,  223,  224,  252,  267,  268,  264,  265,
      237,  278,  258,  259,  262,  269,  263,  270,  276,  271,
      272,  274,  279,  692,  277,  280,  266,  281,  275,  273,

      283,  284,  287,  267,  268,  286,  290,  282,  292,  278,
      291,  293,  294,  692,  285,  295,  276,  296,  692,  288,
      279,  277,  297,  280,  298,  281,  289,  299,  283,  284,
      287,  300,  286,  301,  290,  282,  292,  291,  302,  293,
      294,  285,  303,  295,  304,  296,  288,  305,  692,  692,
      297,  311,  298,  289,  692,  299,  692,  692,  300,  312,
      301,  313,  314,  309,  309,  315,  302,  310,  310,  310,
      303,  304,  210,  210,  210,  305,  307,  307,  307,  311,
      307,  307,  307,  307,  307,  307,  317,  312,  316,  313,
      314,  318,  319,  315,  321,  322,  323,  324,  692,  325,

      320,  329,  692,  330,  331,  692,  332,  333,  307,  307,
      307,  307,  307,  307,  317,  316,  334,  337,  318,  326,
      319,  335,  321,  322,  323,  324,  325,  327,  320,  329,
      330,  336,  331,  332,  338,  333,  349,  328,  339,  340,
      341,  342,  343,  344,  334,  337,  345,  326,  335,  346,
      347,  348,  350,  352,  355,  327,  353,  354,  336,  356,
      692,  358,  338,  349,  328,  359,  339,  340,  341,  342,
      343,  344,  360,  362,  345,  363,  361,  346,  347,  348,
      350,  352,  355,  353,  354,  364,  365,  356,  358,  366,
      692,  367,  368,  359,  369,  692,  370,  373,  374,  371,

      360,  362,  375,  363,  361,  372,  377,  378,  379,  380,
      382,  384,  385,  364,  365,  383,  386,  366,  367,  387,
      368,  388,  369,  370,  391,  373,  374,  371,  394,  389,
      375,  390,  392,  372,  377,  378,  379,  380,  382,  384,
      385,  395,  383,  397,  386,  398,  399,  387,  388,  400,
      401,  403,  391,  402,  404,  394,  389,  405,  390,  406,
      392,  407,  310,  310,  310,  310,  310,  310,  692,  395,
      692,  397,  398,  409,  399,  410,  400,  411,  401,  403,
      402,  412,  404,  413,  405,  414,  415,  406,  416,  407,
      408,  408,  408,  417,  408,  408,  408,  408,  408,  408,

      419,  409,  418,  410,  420,  411,  421,  422,  423,  412,
      424,  413,  425,  414,  415,  426,  416,  427,  428,  429,
      417,  430,  408,  408,  408,  408,  408,  408,  419,  418,
      431,  433,  420,  421,  432,  422,  423,  424,  434,  425,
      435,  436,  426,  437,  427,  438,  428,  429,  430,  439,
      692,  440,  441,  443,  444,  692,  445,  446,  431,  433,
      447,  432,  448,  451,  449,  434,  452,  435,  453,  436,
      437,  454,  456,  438,  455,  457,  458,  439,  440,  441,
      450,  443,  444,  445,  459,  446,  460,  461,  447,  462,
      448,  451,  449,  463,  452,  464,  453,  465,  466,  454,

      456,  455,  467,  457,  458,  468,  469,  450,  470,  471,
      472,  474,  459,  460,  461,  473,  462,  475,  476,  479,
      477,  463,  480,  464,  465,  466,  478,  482,  481,  483,
      467,  484,  485,  468,  469,  470,  486,  471,  472,  474,
      487,  488,  473,  692,  692,  475,  476,  479,  477,  692,
      480,  692,  490,  478,  482,  481,  491,  483,  484,  485,
      492,  493,  494,  495,  486,  496,  497,  498,  487,  488,
      489,  489,  489,  499,  489,  489,  489,  489,  489,  489,
      490,  500,  501,  491,  502,  692,  503,  492,  504,  493,
      494,  495,  496,  505,  497,  498,  506,  507,  508,  510,

      499,  509,  489,  489,  489,  489,  489,  489,  511,  500,
      501,  512,  502,  503,  513,  514,  504,  516,  692,  517,
      518,  505,  519,  520,  506,  507,  508,  510,  509,  521,
      692,  522,  523,  524,  525,  511,  526,  527,  528,  512,
      529,  531,  513,  514,  530,  516,  517,  518,  533,  519,
      535,  520,  537,  538,  692,  532,  539,  521,  522,  540,
      523,  524,  525,  526,  527,  541,  528,  542,  529,  531,
      543,  530,  544,  545,  548,  551,  533,  549,  535,  537,
      550,  538,  532,  552,  539,  553,  540,  554,  555,  556,
      692,  692,  692,  541,  562,  542,  692,  543,  692,  692,

      544,  545,  548,  551,  549,  558,  559,  550,  561,  563,
      566,  552,  564,  553,  565,  554,  555,  556,  557,  557,
      557,  562,  557,  557,  557,  557,  557,  557,  567,  568,
      569,  692,  570,  558,  559,  571,  561,  563,  566,  564,
      572,  565,  573,  574,  575,  576,  577,  578,  579,  581,
      557,  557,  557,  557,  557,  557,  567,  568,  569,  570,
      580,  582,  584,  571,  583,  585,  586,  587,  572,  573,
      574,  588,  575,  576,  577,  578,  579,  581,  589,  590,
      591,  592,  692,  594,  595,  692,  596,  580,  597,  582,
      584,  583,  585,  598,  586,  587,  599,  600,  588,  601,

      602,  603,  692,  692,  692,  605,  589,  590,  591,  592,
      594,  692,  595,  596,  606,  597,  607,  692,  608,  610,
      611,  598,  612,  614,  599,  600,  601,  613,  602,  603,
      604,  604,  604,  605,  604,  604,  604,  604,  604,  604,
      615,  606,  617,  618,  607,  608,  619,  610,  611,  620,
      612,  614,  621,  623,  613,  622,  624,  625,  626,  627,
      692,  692,  604,  604,  604,  604,  604,  604,  615,  617,
      630,  618,  629,  631,  619,  632,  633,  620,  634,  636,
      621,  623,  622,  624,  635,  625,  626,  627,  628,  628,
      628,  637,  628,  628,  628,  628,  628,  628,  630,  629,

      631,  639,  632,  640,  633,  641,  634,  636,  642,  643,
      644,  635,  645,  646,  647,  648,  692,  649,  650,  637,
      628,  628,  628,  628,  628,  628,  651,  652,  639,  653,
      640,  654,  655,  641,  656,  657,  642,  643,  644,  658,
      645,  646,  647,  648,  649,  659,  650,  660,  661,  662,
      663,  692,  664,  665,  651,  652,  666,  653,  668,  654,
      655,  669,  656,  657,  670,  692,  671,  658,  672,  673,
      677,  692,  678,  659,  679,  660,  661,  662,  663,  664,
      665,  675,  681,  666,  680,  668,  685,  676,  682,  669,
      683,  684,  670,  671,  687,  688,  672,  673,  677,  678,

      689,  679,  690,  691,  692,  692,  692,  692,  692,  675,
      681,  680,  692,  685,  676,  692,  682,  692,  683,  684,
      692,  692,  687,  688,  692,  692,  692,  689,  692,  692,
      690,  691,   84,   84,   84,   84,   84,   84,   84,   90,
       90,   90,   90,   90,   90,   90,   91,   91,   91,   91,
       91,   91,   91,   95,   95,   95,   95,   95,   95,   95,
       97,   97,   97,   97,   97,   97,   97,  100,  100,  195,
      692,  692,  195,  195,  195,  195,  196,  692,  196,  196,
      196,  196,  196,  200,  200,  200,  201,  692,  201,  201,
      201,  201,  204,  204,  204,  208,  208,  208,  208,  208,

      208,  208,  211,  211,  308,  308,   11,  692,  692,  692,
      692,  692,  692,  692,  692,  692,  692,  692,  692,  692,
      692,  692,  692,  692,  692,  692,  692,  692,  692,  692,
      692,  692,  692,  692,  692,  692,  692,  692,  692,  692,
      692,  692,  692,  692,  692,  692,  692,  692,  692,  692,
      692,  692,  692,  692,  692,  692,  692,  692,  692,  692,
      692,  692,  692,  692,  692,  692,  692,  692,  692,  692,
      692,  692,  692,  692,  692,  692,  692,  692,  692,  692,
      692
    } ;

static const flex_int16_t yy_chk[1882] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,

        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    5,    5,
        6,    6,    9,    5,   10,    6,    7,    7,    7,    7,
        7,    7,    7,    7,    7,    7,    7,    7,    7,    7,
        7,    7,   19,   34,   19,   19,   19,   20,   20,   25,
       20,   20,   20,   21,   21,   21,   24,   25,   24,   24,
       24,   35,    9,   38,   10,   39,   24,  684,    7,   56,

       34,   56,   56,   56,  673,   57,   57,   25,   57,   57,
       57,   58,   58,   58,   25,  663,   59,  628,  621,   35,
       59,   38,   72,   39,   24,    7,    7,    7,    7,    7,
        8,    8,    8,    8,    8,    8,    8,    8,    8,    8,
        8,    8,    8,    8,    8,    8,   27,  577,   71,   23,
       72,   23,   23,   23,   28,   29,   31,   27,   28,   23,
       27,  563,   31,   29,  115,   29,   27,   28,   75,   87,
       28,  117,    8,   87,   27,   71,  541,  197,   23,  123,
       76,  197,   28,   29,   31,   27,   28,   23,   27,   31,
       29,  115,   29,   27,   28,  492,   75,   28,  117,    8,

        8,    8,    8,    8,   17,   23,  123,   44,   76,   62,
      112,  478,   44,  114,   17,   17,   17,   62,   17,   17,
       17,   17,   17,   17,  477,   30,   33,  101,  101,  101,
      465,   30,  462,  440,   30,   44,   33,   62,  112,   44,
      119,  114,   33,  121,   62,  354,   17,   17,   17,   17,
       17,   17,   26,   30,   33,  294,   26,   43,   26,   30,
       26,   30,  290,   43,   33,  125,   26,   43,  119,   33,
       26,  121,   61,   43,   61,   61,   61,  280,   43,  124,
       26,  275,   61,   36,   26,   36,   26,  256,   26,   36,
       68,   43,  125,   36,   26,   43,   68,   26,   32,   36,

       32,   43,   32,  250,   36,   43,   81,  124,  126,   32,
       61,   81,   32,   36,   41,   32,   41,   36,   68,  127,
       41,   36,   41,   68,   41,   37,   32,   36,   32,   37,
       32,   36,  128,   37,   81,   41,  126,   32,   81,   37,
       32,  129,   32,  208,   41,  135,  127,  199,   41,  192,
       41,  136,   41,   37,  108,   42,  104,   37,   42,   42,
      128,   37,   41,  130,   64,   42,  118,   37,   40,  129,
       42,   46,   40,  135,  118,   64,   40,   46,   64,  136,
       46,   40,   40,   42,   64,   40,   42,   42,   97,   95,
      130,  131,   64,   42,  118,  137,   40,   42,   94,   46,

       40,  118,   93,   64,   40,   46,   64,   46,  134,   40,
       40,   64,   40,   45,   45,   45,   67,   45,  131,  138,
       70,   45,   67,  137,   60,   67,   60,   60,   60,   66,
       70,   89,   45,   53,   60,  134,   70,   66,  140,   66,
      139,   45,   45,   45,   67,   45,   51,  138,   70,   45,
       67,   49,   67,   60,  143,  120,  141,   66,   70,   45,
       54,  120,   60,   70,   66,  140,   66,  144,  139,   65,
       54,   54,   54,   65,   54,   54,   54,   54,   54,   54,
       60,  143,   65,  120,  141,   65,  145,   48,  120,  103,
      146,  103,  103,  103,  147,  144,  152,   65,   47,  103,

      149,   65,   54,   54,   54,   54,   54,   54,   73,   65,
       73,   74,   65,  145,   73,   74,   80,  146,   73,   74,
      150,  147,   80,  152,   73,   74,   80,  103,  149,   73,
       79,   22,   80,   79,   79,   83,   16,   80,   73,   74,
       79,   83,   73,   74,   83,   79,   73,   74,  150,   78,
       80,   78,   73,   74,   80,   78,   73,   78,   79,   78,
       80,   79,   79,   83,   80,  154,   13,   11,   79,   83,
       78,   83,   79,    0,  106,    0,  106,  106,  106,   78,
      209,  209,  209,   78,  106,   78,  102,   78,  102,  102,
      102,  105,  154,  105,  105,  105,  102,   78,   99,   99,

       99,  105,   99,   99,   99,   99,   99,   99,  107,  107,
      107,  151,  106,    0,    0,  102,  107,  109,  109,  109,
      105,  155,  110,  110,  102,  109,  110,  110,  110,  105,
       99,   99,   99,   99,   99,   99,  132,  122,  133,  151,
      132,  153,  102,  148,  107,  122,  122,  105,  148,  155,
      157,  158,  133,  109,  153,    0,  153,  156,  160,  156,
      161,  162,  163,  164,  132,  122,  133,  132,  159,  153,
      165,  148,  163,  122,  122,  148,  159,  159,  157,  158,
      133,  167,  153,  153,  156,  160,  156,  161,  166,  162,
      163,  164,  169,    0,  166,  170,  159,  171,  165,  163,

      172,  173,  175,  159,  159,  174,  176,  171,  178,  167,
      177,  179,  180,    0,  173,  181,  166,  182,    0,  175,
      169,  166,  183,  170,  184,  171,  175,  185,  172,  173,
      175,  186,  174,  187,  176,  171,  178,  177,  188,  179,
      180,  173,  189,  181,  190,  182,  175,  191,    0,    0,
      183,  212,  184,  175,    0,  185,    0,    0,  186,  213,
      187,  214,  215,  207,  207,  216,  188,  207,  207,  207,
      189,  190,  210,  210,  210,  191,  203,  203,  203,  212,
      203,  203,  203,  203,  203,  203,  218,  213,  217,  214,
      215,  219,  220,  216,  221,  222,  223,  224,    0,  225,

      220,  227,    0,  228,  229,    0,  230,  231,  203,  203,
      203,  203,  203,  203,  218,  217,  232,  236,  219,  226,
      220,  233,  221,  222,  223,  224,  225,  226,  220,  227,
      228,  234,  229,  230,  237,  231,  248,  226,  238,  239,
      240,  241,  242,  243,  232,  236,  244,  226,  233,  245,
      246,  247,  249,  251,  254,  226,  252,  253,  234,  255,
        0,  257,  237,  248,  226,  258,  238,  239,  240,  241,
      242,  243,  259,  260,  244,  261,  259,  245,  246,  247,
      249,  251,  254,  252,  253,  262,  263,  255,  257,  264,
        0,  265,  266,  258,  267,    0,  268,  270,  272,  269,

      259,  260,  273,  261,  259,  269,  276,  277,  278,  279,
      281,  282,  283,  262,  263,  281,  284,  264,  265,  285,
      266,  286,  267,  268,  288,  270,  272,  269,  291,  287,
      273,  287,  289,  269,  276,  277,  278,  279,  281,  282,
      283,  292,  281,  295,  284,  296,  297,  285,  286,  298,
      299,  301,  288,  300,  302,  291,  287,  303,  287,  304,
      289,  305,  309,  309,  309,  310,  310,  310,    0,  292,
        0,  295,  296,  311,  297,  312,  298,  313,  299,  301,
      300,  314,  302,  316,  303,  317,  318,  304,  319,  305,
      307,  307,  307,  320,  307,  307,  307,  307,  307,  307,

      324,  311,  323,  312,  325,  313,  326,  327,  329,  314,
      331,  316,  333,  317,  318,  334,  319,  335,  337,  339,
      320,  340,  307,  307,  307,  307,  307,  307,  324,  323,
      341,  343,  325,  326,  342,  327,  329,  331,  344,  333,
      345,  346,  334,  347,  335,  348,  337,  339,  340,  349,
        0,  351,  352,  355,  356,    0,  357,  358,  341,  343,
      359,  342,  360,  363,  361,  344,  364,  345,  365,  346,
      347,  367,  370,  348,  368,  371,  372,  349,  351,  352,
      361,  355,  356,  357,  373,  358,  374,  375,  359,  376,
      360,  363,  361,  377,  364,  379,  365,  380,  381,  367,

      370,  368,  382,  371,  372,  383,  384,  361,  385,  386,
      388,  390,  373,  374,  375,  389,  376,  391,  392,  395,
      393,  377,  396,  379,  380,  381,  393,  397,  396,  399,
      382,  400,  401,  383,  384,  385,  402,  386,  388,  390,
      403,  405,  389,    0,    0,  391,  392,  395,  393,    0,
      396,    0,  409,  393,  397,  396,  410,  399,  400,  401,
      411,  412,  413,  414,  402,  415,  416,  417,  403,  405,
      408,  408,  408,  418,  408,  408,  408,  408,  408,  408,
      409,  419,  421,  410,  422,    0,  423,  411,  424,  412,
      413,  414,  415,  426,  416,  417,  430,  431,  432,  435,

      418,  433,  408,  408,  408,  408,  408,  408,  436,  419,
      421,  437,  422,  423,  438,  439,  424,  441,    0,  442,
      443,  426,  445,  447,  430,  431,  432,  435,  433,  448,
        0,  449,  450,  451,  453,  436,  454,  455,  457,  437,
      458,  460,  438,  439,  459,  441,  442,  443,  461,  445,
      464,  447,  466,  467,    0,  460,  468,  448,  449,  469,
      450,  451,  453,  454,  455,  471,  457,  472,  458,  460,
      473,  459,  474,  475,  479,  482,  461,  480,  464,  466,
      481,  467,  460,  483,  468,  484,  469,  485,  486,  487,
        0,    0,    0,  471,  497,  472,    0,  473,    0,    0,

      474,  475,  479,  482,  480,  490,  491,  481,  495,  498,
      503,  483,  500,  484,  501,  485,  486,  487,  489,  489,
      489,  497,  489,  489,  489,  489,  489,  489,  504,  505,
      506,    0,  508,  490,  491,  510,  495,  498,  503,  500,
      512,  501,  513,  514,  515,  516,  517,  519,  520,  524,
      489,  489,  489,  489,  489,  489,  504,  505,  506,  508,
      521,  527,  529,  510,  528,  531,  533,  534,  512,  513,
      514,  536,  515,  516,  517,  519,  520,  524,  537,  538,
      539,  540,    0,  546,  547,    0,  548,  521,  549,  527,
      529,  528,  531,  550,  533,  534,  551,  553,  536,  554,

      555,  556,    0,    0,    0,  558,  537,  538,  539,  540,
      546,    0,  547,  548,  559,  549,  560,    0,  562,  566,
      567,  550,  568,  572,  551,  553,  554,  571,  555,  556,
      557,  557,  557,  558,  557,  557,  557,  557,  557,  557,
      576,  559,  581,  583,  560,  562,  584,  566,  567,  586,
      568,  572,  588,  592,  571,  590,  593,  596,  599,  602,
        0,    0,  557,  557,  557,  557,  557,  557,  576,  581,
      606,  583,  605,  607,  584,  609,  610,  586,  613,  617,
      588,  592,  590,  593,  616,  596,  599,  602,  604,  604,
      604,  618,  604,  604,  604,  604,  604,  604,  606,  605,

      607,  622,  609,  623,  610,  624,  613,  617,  626,  630,
      631,  616,  632,  633,  634,  635,    0,  636,  637,  618,
      604,  604,  604,  604,  604,  604,  638,  641,  622,  644,
      623,  645,  646,  624,  648,  651,  626,  630,  631,  652,
      632,  633,  634,  635,  636,  653,  637,  655,  656,  657,
      658,    0,  660,  661,  638,  641,  662,  644,  664,  645,
      646,  667,  648,  651,  669,    0,  670,  652,  671,  672,
      675,    0,  676,  653,  677,  655,  656,  657,  658,  660,
      661,  674,  679,  662,  678,  664,  683,  674,  680,  667,
      681,  682,  669,  670,  686,  687,  671,  672,  675,  676,

      688,  677,  689,  690,    0,    0,    0,    0,    0,  674,
      679,  678,    0,  683,  674,    0,  680,    0,  681,  682,
        0,    0,  686,  687,    0,    0,    0,  688,    0,    0,
      689,  690,  693,  693,  693,  693,  693,  693,  693,  694,
      694,  694,  694,  694,  694,  694,  695,  695,  695,  695,
      695,  695,  695,  696,  696,  696,  696,  696,  696,  696,
      697,  697,  697,  697,  697,  697,  697,  698,  698,  699,
        0,    0,  699,  699,  699,  699,  700,    0,  700,  700,
      700,  700,  700,  701,  701,  701,  702,    0,  702,  702,
      702,  702,  703,  703,  703,  704,  704,  704,  704,  704,

      704,  704,  705,  705,  706,  706,  692,  692,  692,  692,
      692,  692,  692,  692,  692,  692,  692,  692,  692,  692,
      692,  692,  692,  692,  692,  692,  692,  692,  692,  692,
      692,  692,  692,  692,  692,  692,  692,  692,  692,  692,
      692,  692,  692,  692,  692,  692,  692,  692,  692,  692,
      692,  692,  692,  692,  692,  692,  692,  692,  692,  692,
      692,  692,  692,  692,  692,  692,  692,  692,  692,  692,
      692,  692,  692,  692,  692,  692,  692,  692,  692,  692,
      692
    } ;

static yy_state_type yy_last_accepting_state;
static char *yy_last_accepting_cpos;

extern int yy_flex_debug;
int yy_flex_debug = 0;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
static int yy_more_flag = 0;
static int yy_more_len = 0;
#define yymore() ((yy_more_flag) = 1)
#define YY_MORE_ADJ (yy_more_len)
#define YY_RESTORE_YY_MORE_OFFSET
char *yytext;
#line 1 "kate_lexer.l"
/* Copyright (C) 2008 Vincent Penquerc'h.
   This file is part of the Kate codec library.
   Written by Vincent Penquerc'h.

   Use, distribution and reproduction of this library is governed
   by a BSD style source license included with this source in the
   file 'COPYING'. Please read these terms before distributing. */
#line 11 "kate_lexer.l"

#define KATE_INTERNAL
#include "kate_internal.h"

#include <stdarg.h>
#include <stdlib.h>
#ifdef HAVE_STRING_H
#include <string.h>
#endif
#include "kate/kate.h"
#include "katedesc.h"
#include "kate_parser.h"

#define YY_DECL extern int katedesc_lex(YYSTYPE *lvalp)

static int previous_state=-1;

static size_t nmacros=0;
static char **macro_names=NULL;
static char **macro_bodies=NULL;

static void replace_macro(const char *name);
static const char *find_macro(const char *name);

static void process_nlines(const char *text);

static int freeze_nlines=0;

static YY_BUFFER_STATE main_buffer=NULL;

int nlines=1;

/* string   [a-zA-Z ,\.;:!\?\-\(\)\'\`0-9#/\\:@%_]+ */

#line 1394 "kate_lexer.c"

/* single_quoted_string \'[^\<\>\&']*\' */
/* double_quoted_string \"[^\<\>\&"]*\" */
/* single_quoted_string \'[^']*\' */
/* double_quoted_string \"[^"\n]*\" */
#line 1400 "kate_lexer.c"

#define INITIAL 0
#define NORMAL 1
#define BLOCK_COMMENT 2
#define MACRO_1 3
#define MACRO_2 4

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals ( void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int yylex_destroy ( void );

int yyget_debug ( void );

void yyset_debug ( int debug_flag  );

YY_EXTRA_TYPE yyget_extra ( void );

void yyset_extra ( YY_EXTRA_TYPE user_defined  );

FILE *yyget_in ( void );

void yyset_in  ( FILE * _in_str  );

FILE *yyget_out ( void );

void yyset_out  ( FILE * _out_str  );

			int yyget_leng ( void );

char *yyget_text ( void );

int yyget_lineno ( void );

void yyset_lineno ( int _line_number  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap ( void );
#else
extern int yywrap ( void );
#endif
#endif

#ifndef YY_NO_UNPUT
    
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy ( char *, const char *, int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen ( const char * );
#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
static int yyinput ( void );
#else
static int input ( void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( yytext, (size_t) yyleng, 1, yyout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		int n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = (int) fread(buf, 1, (yy_size_t) max_size, yyin)) == 0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex (void);

#define YY_DECL int yylex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK /*LINTED*/break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	yy_state_type yy_current_state;
	char *yy_cp, *yy_bp;
	int yy_act;
    
	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer( yyin, YY_BUF_SIZE );
		}

		yy_load_buffer_state(  );
		}

	{
#line 81 "kate_lexer.l"



#line 1623 "kate_lexer.c"

	while ( /*CONSTCOND*/1 )		/* loops until end-of-file is reached */
		{
		(yy_more_len) = 0;
		if ( (yy_more_flag) )
			{
			(yy_more_len) = (int) ((yy_c_buf_p) - (yytext_ptr));
			(yy_more_flag) = 0;
			}
		yy_cp = (yy_c_buf_p);

		/* Support of yytext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
yy_match:
		do
			{
			YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)] ;
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 693 )
					yy_c = yy_meta[yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
			++yy_cp;
			}
		while ( yy_current_state != 692 );
		yy_cp = (yy_last_accepting_cpos);
		yy_current_state = (yy_last_accepting_state);

yy_find_action:
		yy_act = yy_accept[yy_current_state];

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case 1:
YY_RULE_SETUP
#line 84 "kate_lexer.l"
{
                                      fprintf(stderr,"This file seems to be encoded in UTF-16, Kate only supports UTF-8\n");
                                      fprintf(stderr,"You will need to convert it to UTF-8 first (eg, use iconv)\n");
                                    }
	YY_BREAK
case 2:
YY_RULE_SETUP
#line 88 "kate_lexer.l"
{BEGIN(NORMAL);}
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 89 "kate_lexer.l"
{yyless(0);BEGIN(NORMAL);}
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 91 "kate_lexer.l"
{previous_state=NORMAL;BEGIN(BLOCK_COMMENT);}
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 92 "kate_lexer.l"
{}
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 93 "kate_lexer.l"
{}
	YY_BREAK
case 7:
/* rule 7 can match eol */
YY_RULE_SETUP
#line 94 "kate_lexer.l"
{if (!freeze_nlines) nlines++;}
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 95 "kate_lexer.l"
{BEGIN(previous_state);}
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 97 "kate_lexer.l"
{}
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 98 "kate_lexer.l"
{BEGIN(MACRO_2);lvalp->string=yytext;return IDENTIFIER;}
	YY_BREAK
case 11:
/* rule 11 can match eol */
YY_RULE_SETUP
#line 100 "kate_lexer.l"
{yytext[yyleng-2]=' ';yymore();}
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 101 "kate_lexer.l"
{yymore();}
	YY_BREAK
case 13:
/* rule 13 can match eol */
YY_RULE_SETUP
#line 102 "kate_lexer.l"
{BEGIN(previous_state);lvalp->string=yytext;process_nlines(yytext);return MACRO_BODY;}
	YY_BREAK
case 14:
/* rule 14 can match eol */
YY_RULE_SETUP
#line 104 "kate_lexer.l"
{if (!freeze_nlines) nlines++;}
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 105 "kate_lexer.l"
{}
	YY_BREAK
case 16:
/* rule 16 can match eol */
YY_RULE_SETUP
#line 106 "kate_lexer.l"
{if (!freeze_nlines) nlines++;}
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 108 "kate_lexer.l"
{return KATE;}
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 110 "kate_lexer.l"
{replace_macro(katedesc_text+1);}
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 112 "kate_lexer.l"
{return DEFS;}
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 113 "kate_lexer.l"
{return EVENT;}
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 114 "kate_lexer.l"
{return LANGUAGE;}
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 115 "kate_lexer.l"
{return COMMENT;}
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 116 "kate_lexer.l"
{return DEFINE;}
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 117 "kate_lexer.l"
{return STYLE;}
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 118 "kate_lexer.l"
{return REGION;}
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 119 "kate_lexer.l"
{return CURVE;}
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 120 "kate_lexer.l"
{return TEXT;}
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 121 "kate_lexer.l"
{return BACKGROUND;}
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 122 "kate_lexer.l"
{return BACKGROUND;}
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 123 "kate_lexer.l"
{return COLOR;}
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 124 "kate_lexer.l"
{return MARKER;}
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 125 "kate_lexer.l"
{return POSITION;}
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 126 "kate_lexer.l"
{return SIZE;}
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 127 "kate_lexer.l"
{return HALIGN;}
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 128 "kate_lexer.l"
{return VALIGN;}
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 129 "kate_lexer.l"
{return DEFAULT;}
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 130 "kate_lexer.l"
{return POINTS;}
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 131 "kate_lexer.l"
{return HLEFT;}
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 132 "kate_lexer.l"
{return HCENTER;}
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 133 "kate_lexer.l"
{return HRIGHT;}
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 134 "kate_lexer.l"
{return VTOP;}
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 135 "kate_lexer.l"
{return VCENTER;}
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 136 "kate_lexer.l"
{return VBOTTOM;}
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 137 "kate_lexer.l"
{return STARTS;}
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 138 "kate_lexer.l"
{return ENDS;}
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 139 "kate_lexer.l"
{return AT;}
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 140 "kate_lexer.l"
{return START;}
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 141 "kate_lexer.l"
{return END;}
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 142 "kate_lexer.l"
{return TIME;}
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 143 "kate_lexer.l"
{return DURATION;}
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 144 "kate_lexer.l"
{return ARROW;}
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 145 "kate_lexer.l"
{return MOTION;}
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 146 "kate_lexer.l"
{return MAPPING;}
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 147 "kate_lexer.l"
{return FRAME;}
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 148 "kate_lexer.l"
{return NONE;}
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 149 "kate_lexer.l"
{return SEMANTICS;}
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 150 "kate_lexer.l"
{return EXTERNAL;}
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 151 "kate_lexer.l"
{return INTERNAL;}
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 152 "kate_lexer.l"
{return ALIGNMENT;}
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 153 "kate_lexer.l"
{return RG;}
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 154 "kate_lexer.l"
{return BA;}
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 155 "kate_lexer.l"
{return FOR;}
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 156 "kate_lexer.l"
{return FROM;}
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 157 "kate_lexer.l"
{return TO;}
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 158 "kate_lexer.l"
{return MACRO;}
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 159 "kate_lexer.l"
{return TIMEBASE;}
	YY_BREAK
case 67:
YY_RULE_SETUP
#line 160 "kate_lexer.l"
{return MORPH;}
	YY_BREAK
case 68:
YY_RULE_SETUP
#line 161 "kate_lexer.l"
{return SECONDARY;}
	YY_BREAK
case 69:
YY_RULE_SETUP
#line 162 "kate_lexer.l"
{return PATH;}
	YY_BREAK
case 70:
YY_RULE_SETUP
#line 163 "kate_lexer.l"
{return SECTION;}
	YY_BREAK
case 71:
YY_RULE_SETUP
#line 164 "kate_lexer.l"
{return DIRECTIONALITY;}
	YY_BREAK
case 72:
YY_RULE_SETUP
#line 165 "kate_lexer.l"
{return PALETTE;}
	YY_BREAK
case 73:
YY_RULE_SETUP
#line 166 "kate_lexer.l"
{return BITMAP;}
	YY_BREAK
case 74:
YY_RULE_SETUP
#line 167 "kate_lexer.l"
{return COLORS;}
	YY_BREAK
case 75:
YY_RULE_SETUP
#line 168 "kate_lexer.l"
{return FONT;}
	YY_BREAK
case 76:
YY_RULE_SETUP
#line 169 "kate_lexer.l"
{return RANGE;}
	YY_BREAK
case 77:
YY_RULE_SETUP
#line 170 "kate_lexer.l"
{return FIRST;}
	YY_BREAK
case 78:
YY_RULE_SETUP
#line 171 "kate_lexer.l"
{return LAST;}
	YY_BREAK
case 79:
YY_RULE_SETUP
#line 172 "kate_lexer.l"
{return CODE;}
	YY_BREAK
case 80:
YY_RULE_SETUP
#line 173 "kate_lexer.l"
{return POINT;}
	YY_BREAK
case 81:
YY_RULE_SETUP
#line 174 "kate_lexer.l"
{return USER;}
	YY_BREAK
case 82:
YY_RULE_SETUP
#line 175 "kate_lexer.l"
{return SOURCE;}
	YY_BREAK
case 83:
YY_RULE_SETUP
#line 176 "kate_lexer.l"
{return DRAW;}
	YY_BREAK
case 84:
YY_RULE_SETUP
#line 177 "kate_lexer.l"
{return VISIBLE;}
	YY_BREAK
case 85:
YY_RULE_SETUP
#line 178 "kate_lexer.l"
{return CATEGORY;}
	YY_BREAK
case 86:
YY_RULE_SETUP
#line 179 "kate_lexer.l"
{return ID;}
	YY_BREAK
case 87:
YY_RULE_SETUP
#line 180 "kate_lexer.l"
{return BOLD;}
	YY_BREAK
case 88:
YY_RULE_SETUP
#line 181 "kate_lexer.l"
{return ITALICS;}
	YY_BREAK
case 89:
YY_RULE_SETUP
#line 182 "kate_lexer.l"
{return UNDERLINE;}
	YY_BREAK
case 90:
YY_RULE_SETUP
#line 183 "kate_lexer.l"
{return STRIKE;}
	YY_BREAK
case 91:
YY_RULE_SETUP
#line 184 "kate_lexer.l"
{return PERIODIC;}
	YY_BREAK
case 92:
YY_RULE_SETUP
#line 185 "kate_lexer.l"
{return GRANULE;}
	YY_BREAK
case 93:
YY_RULE_SETUP
#line 186 "kate_lexer.l"
{return RATE;}
	YY_BREAK
case 94:
YY_RULE_SETUP
#line 187 "kate_lexer.l"
{return SHIFT;}
	YY_BREAK
case 95:
YY_RULE_SETUP
#line 188 "kate_lexer.l"
{return WIDTH;}
	YY_BREAK
case 96:
YY_RULE_SETUP
#line 189 "kate_lexer.l"
{return HEIGHT;}
	YY_BREAK
case 97:
YY_RULE_SETUP
#line 190 "kate_lexer.l"
{return LEFT;}
	YY_BREAK
case 98:
YY_RULE_SETUP
#line 191 "kate_lexer.l"
{return TOP;}
	YY_BREAK
case 99:
YY_RULE_SETUP
#line 192 "kate_lexer.l"
{return RIGHT;}
	YY_BREAK
case 100:
YY_RULE_SETUP
#line 193 "kate_lexer.l"
{return BOTTOM;}
	YY_BREAK
case 101:
YY_RULE_SETUP
#line 194 "kate_lexer.l"
{return MARGIN;}
	YY_BREAK
case 102:
YY_RULE_SETUP
#line 195 "kate_lexer.l"
{return MARGINS;}
	YY_BREAK
case 103:
YY_RULE_SETUP
#line 196 "kate_lexer.l"
{return HORIZONTAL;}
	YY_BREAK
case 104:
YY_RULE_SETUP
#line 197 "kate_lexer.l"
{return VERTICAL;}
	YY_BREAK
case 105:
YY_RULE_SETUP
#line 198 "kate_lexer.l"
{return PNG;}
	YY_BREAK
case 106:
YY_RULE_SETUP
#line 199 "kate_lexer.l"
{return JUSTIFY;}
	YY_BREAK
case 107:
YY_RULE_SETUP
#line 200 "kate_lexer.l"
{return CLIP;}
	YY_BREAK
case 108:
YY_RULE_SETUP
#line 201 "kate_lexer.l"
{return PRE;}
	YY_BREAK
case 109:
YY_RULE_SETUP
#line 202 "kate_lexer.l"
{return MARKUP;}
	YY_BREAK
case 110:
YY_RULE_SETUP
#line 203 "kate_lexer.l"
{return CANVAS;}
	YY_BREAK
case 111:
YY_RULE_SETUP
#line 204 "kate_lexer.l"
{return LOCAL;}
	YY_BREAK
case 112:
YY_RULE_SETUP
#line 205 "kate_lexer.l"
{return OFFSET;}
	YY_BREAK
case 113:
YY_RULE_SETUP
#line 206 "kate_lexer.l"
{return WRAP;}
	YY_BREAK
case 114:
YY_RULE_SETUP
#line 207 "kate_lexer.l"
{return WORD;}
	YY_BREAK
case 115:
YY_RULE_SETUP
#line 208 "kate_lexer.l"
{return META;}
	YY_BREAK
case 116:
YY_RULE_SETUP
#line 212 "kate_lexer.l"
{return L2R_T2B;}
	YY_BREAK
case 117:
YY_RULE_SETUP
#line 213 "kate_lexer.l"
{return R2L_T2B;}
	YY_BREAK
case 118:
YY_RULE_SETUP
#line 214 "kate_lexer.l"
{return T2B_R2L;}
	YY_BREAK
case 119:
YY_RULE_SETUP
#line 215 "kate_lexer.l"
{return T2B_L2R;}
	YY_BREAK
case 120:
YY_RULE_SETUP
#line 217 "kate_lexer.l"
{lvalp->number=kate_pixel;return METRIC;}
	YY_BREAK
case 121:
YY_RULE_SETUP
#line 218 "kate_lexer.l"
{lvalp->number=kate_pixel;return METRIC;}
	YY_BREAK
case 122:
YY_RULE_SETUP
#line 219 "kate_lexer.l"
{lvalp->number=kate_percentage;return METRIC;}
	YY_BREAK
case 123:
YY_RULE_SETUP
#line 220 "kate_lexer.l"
{lvalp->number=kate_percentage;return METRIC;}
	YY_BREAK
case 124:
YY_RULE_SETUP
#line 221 "kate_lexer.l"
{lvalp->number=kate_millionths;return METRIC;}
	YY_BREAK
case 125:
YY_RULE_SETUP
#line 223 "kate_lexer.l"
{return STATIC;}
	YY_BREAK
case 126:
YY_RULE_SETUP
#line 224 "kate_lexer.l"
{return LINEAR;}
	YY_BREAK
case 127:
YY_RULE_SETUP
#line 225 "kate_lexer.l"
{return CATMULL_ROM;}
	YY_BREAK
case 128:
YY_RULE_SETUP
#line 226 "kate_lexer.l"
{return BEZIER_CUBIC;}
	YY_BREAK
case 129:
YY_RULE_SETUP
#line 227 "kate_lexer.l"
{return BSPLINE;}
	YY_BREAK
case 130:
YY_RULE_SETUP
#line 229 "kate_lexer.l"
{return SIMPLE_TIMED_GLYPH_MARKER;}
	YY_BREAK
case 131:
YY_RULE_SETUP
#line 230 "kate_lexer.l"
{return SIMPLE_TIMED_GLYPH_STYLE_MORPH;}
	YY_BREAK
case 132:
YY_RULE_SETUP
#line 231 "kate_lexer.l"
{return GLYPH;}
	YY_BREAK
case 133:
YY_RULE_SETUP
#line 232 "kate_lexer.l"
{return POINTER;}
	YY_BREAK
case 134:
YY_RULE_SETUP
#line 233 "kate_lexer.l"
{return IN;}
	YY_BREAK
case 135:
YY_RULE_SETUP
#line 234 "kate_lexer.l"
{return PAUSE;}
	YY_BREAK
case 136:
/* rule 136 can match eol */
YY_RULE_SETUP
#line 236 "kate_lexer.l"
{
                                 katedesc_text[strlen(katedesc_text)-1]=0;
                                 lvalp->string=katedesc_text+1;
                                 process_nlines(katedesc_text);
                                 return STRING;
                               }
	YY_BREAK
case 137:
YY_RULE_SETUP
#line 242 "kate_lexer.l"
{lvalp->unumber=strtoul(katedesc_text,NULL,10);return UNUMBER;}
	YY_BREAK
case 138:
YY_RULE_SETUP
#line 243 "kate_lexer.l"
{lvalp->unumber=strtoul(katedesc_text,NULL,16);return UNUMBER;}
	YY_BREAK
case 139:
YY_RULE_SETUP
#line 244 "kate_lexer.l"
{lvalp->number=strtol(katedesc_text,NULL,10);return NUMBER;}
	YY_BREAK
case 140:
YY_RULE_SETUP
#line 245 "kate_lexer.l"
{lvalp->number=strtol(katedesc_text,NULL,16);return NUMBER;}
	YY_BREAK
case 141:
YY_RULE_SETUP
#line 246 "kate_lexer.l"
{lvalp->fp=(kate_float)atof(katedesc_text);return FLOAT;}
	YY_BREAK
case 142:
YY_RULE_SETUP
#line 247 "kate_lexer.l"
{lvalp->color=strtol(katedesc_text+1,NULL,16);return COLORSPEC;}
	YY_BREAK
case 143:
YY_RULE_SETUP
#line 248 "kate_lexer.l"
{lvalp->color=strtol(katedesc_text+1,NULL,16);return COLORSPEC;}
	YY_BREAK
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(NORMAL):
case YY_STATE_EOF(BLOCK_COMMENT):
case YY_STATE_EOF(MACRO_1):
case YY_STATE_EOF(MACRO_2):
#line 251 "kate_lexer.l"
{
                               katedesc_text="<EOF>";
                               if (freeze_nlines) --freeze_nlines;
                               yy_delete_buffer(YY_CURRENT_BUFFER);
                               if (main_buffer) {
                                 yy_switch_to_buffer(main_buffer);
                                 main_buffer=NULL;
                               }
                               else yyterminate();
                             }
	YY_BREAK
case 144:
YY_RULE_SETUP
#line 262 "kate_lexer.l"
{return katedesc_text[0];}
	YY_BREAK
case 145:
YY_RULE_SETUP
#line 265 "kate_lexer.l"
ECHO;
	YY_BREAK
#line 2438 "kate_lexer.c"

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_last_accepting_cpos);
				yy_current_state = (yy_last_accepting_state);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( yywrap(  ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
	} /* end of user's declarations */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	char *source = (yytext_ptr);
	int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr) - 1);

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER_LVALUE;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					yyrealloc( (void *) b->yy_ch_buf,
							 (yy_size_t) (b->yy_buf_size + 2)  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = NULL;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart( yyin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if (((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		int new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) yyrealloc(
			(void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf, (yy_size_t) new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
		/* "- 2" to take care of EOB's */
		YY_CURRENT_BUFFER_LVALUE->yy_buf_size = (int) (new_size - 2);
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	yy_state_type yy_current_state;
	char *yy_cp;
    
	yy_current_state = (yy_start);

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 693 )
				yy_c = yy_meta[yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	int yy_is_jam;
    	char *yy_cp = (yy_c_buf_p);

	YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 693 )
			yy_c = yy_meta[yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
	yy_is_jam = (yy_current_state == 692);

		return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_UNPUT

#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			int offset = (int) ((yy_c_buf_p) - (yytext_ptr));
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart( yyin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap(  ) )
						return 0;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve yytext */
	(yy_hold_char) = *++(yy_c_buf_p);

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyrestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer( yyin, YY_BUF_SIZE );
	}

	yy_init_buffer( YY_CURRENT_BUFFER, input_file );
	yy_load_buffer_state(  );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state(  );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void yy_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc( (yy_size_t) (b->yy_buf_size + 2)  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer( b, file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * 
 */
    void yy_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree( (void *) b->yy_ch_buf  );

	yyfree( (void *) b  );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	yy_flush_buffer( b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void yy_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state(  );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack();

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state(  );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void yypop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state(  );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack (void)
{
	yy_size_t num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
      num_to_alloc = 1; /* After all that talk, this was set to 1 anyways... */
		(yy_buffer_stack) = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));

		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		yy_size_t grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return NULL;

	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = (int) (size - 2);	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = NULL;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer( b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (const char * yystr )
{
    
	return yy_scan_bytes( yystr, (int) strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (const char * yybytes, int  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = (yy_size_t) (_yybytes_len + 2);
	buf = (char *) yyalloc( n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer( buf, n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yynoreturn yy_fatal_error (const char* msg )
{
			fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = (yy_hold_char); \
		(yy_c_buf_p) = yytext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int yyget_lineno  (void)
{
    
    return yylineno;
}

/** Get the input stream.
 * 
 */
FILE *yyget_in  (void)
{
        return yyin;
}

/** Get the output stream.
 * 
 */
FILE *yyget_out  (void)
{
        return yyout;
}

/** Get the length of the current token.
 * 
 */
int yyget_leng  (void)
{
        return yyleng;
}

/** Get the current token.
 * 
 */

char *yyget_text  (void)
{
        return yytext;
}

/** Set the current line number.
 * @param _line_number line number
 * 
 */
void yyset_lineno (int  _line_number )
{
    
    yylineno = _line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param _in_str A readable stream.
 * 
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  _in_str )
{
        yyin = _in_str ;
}

void yyset_out (FILE *  _out_str )
{
        yyout = _out_str ;
}

int yyget_debug  (void)
{
        return yy_flex_debug;
}

void yyset_debug (int  _bdebug )
{
        yy_flex_debug = _bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    (yy_buffer_stack) = NULL;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = NULL;
    (yy_init) = 0;
    (yy_start) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = NULL;
    yyout = NULL;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer( YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state();
	}

	/* Destroy the stack itself. */
	yyfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, const char * s2, int n )
{
		
	int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (const char * s )
{
	int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *yyalloc (yy_size_t  size )
{
			return malloc(size);
}

void *yyrealloc  (void * ptr, yy_size_t  size )
{
		
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return realloc(ptr, size);
}

void yyfree (void * ptr )
{
			free( (char *) ptr );	/* see yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 265 "kate_lexer.l"


int katedesc_wrap()
{
  return 1;
}

void set_macro_mode()
{
  BEGIN(MACRO_1);
}

void unset_macro_mode()
{
  BEGIN(NORMAL);
}

static void replace_macro(const char *name)
{
  const char *body=find_macro(name);
  if (body) {
    ++freeze_nlines;
    main_buffer=YY_CURRENT_BUFFER;
    yy_scan_string(body);
  }
}

void add_macro(const char *name,const char *body)
{
  size_t nlen,blen;

  if (!name || !body) {
    katedesc_error("name and body cannot be null");
    exit(-1);
  }

  ++nmacros;
  macro_names=(char**)kate_realloc(macro_names,nmacros*sizeof(char*));
  macro_bodies=(char**)kate_realloc(macro_bodies,nmacros*sizeof(char*));
  if (!macro_names || !macro_bodies) {
    katedesc_error("out of memory");
    exit(-1);
  }

  nlen=strlen(name);
  blen=strlen(body);
  macro_names[nmacros-1]=kate_malloc(nlen+1);
  macro_bodies[nmacros-1]=kate_malloc(blen+1);
  if (!macro_names[nmacros-1] || !macro_bodies[nmacros-1]) {
    katedesc_error("out of memory");
    exit(-1);
  }
  strcpy(macro_names[nmacros-1],name);
  strcpy(macro_bodies[nmacros-1],body);
}

static const char *find_macro(const char *name)
{
  size_t n;
  if (!name) {
    katedesc_error("macro name cannot be null");
    exit(-1);
  }
  for (n=0;n<nmacros;++n) {
    if (!strcmp(macro_names[n],name)) return macro_bodies[n];
  }
  katedesc_error("undefined macro");
  return NULL;
}

void free_macros(void)
{
  size_t n;
  for (n=0;n<nmacros;++n) {
    kate_free(macro_names[n]);
    kate_free(macro_bodies[n]);
  }
  kate_free(macro_names);
  kate_free(macro_bodies);
}

static int get_nlines(const char *text)
{
  int text_nlines=0;
  if (!text) {
    katedesc_error("null text");
    return 0;
  }
  while (*text) if (*text++=='\n') ++text_nlines;
  return text_nlines;
}

static void process_nlines(const char *text)
{
  if (!freeze_nlines) {
    nlines+=get_nlines(text);
  }
}

void cleanup_lexer(void)
{
#ifdef FLEX_SCANNER
#if (YY_FLEX_MAJOR_VERSION+0)*0x10000+(YY_FLEX_MINOR_VERSION+0)*0x100+(YY_FLEX_SUBMINOR_VERSION+0)>=0x020509
  katedesc_lex_destroy();
#endif
#endif
}


